plugin_macros is a rust crate that provide a sequence of helper function to allow the user of the API to write a plugin with less code.
author: https://github.com/vincenzopalazzo
Macros
- plugin
- procedural macros that can be used wit the following code
Attribute Macros
- notification
- procedural macros that can be used wit the following code
- rpc_
method - procedural macros that can be used wit the following code